Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(195)

Unified Diff: media/audio/audio_util.h

Issue 9655018: Make AudioParameters a class instead of a struct (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix copyright years Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/audio/audio_parameters_unittest.cc ('k') | media/audio/audio_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/audio/audio_util.h
diff --git a/media/audio/audio_util.h b/media/audio/audio_util.h
index 81f6da2b4f9d51b722af8a7c008e4b1183072e19..11ee38e97f096d2afb7635db96d35614e2c378f2 100644
--- a/media/audio/audio_util.h
+++ b/media/audio/audio_util.h
@@ -9,10 +9,9 @@
#include <vector>
#include "base/basictypes.h"
+#include "media/base/channel_layout.h"
#include "media/base/media_export.h"
-struct AudioParameters;
-
namespace base {
class SharedMemory;
}
@@ -92,10 +91,10 @@ MEDIA_EXPORT void InterleaveFloatToInt16(const std::vector<float*>& source,
size_t number_of_frames);
// Returns the default audio output hardware sample-rate.
-MEDIA_EXPORT double GetAudioHardwareSampleRate();
+MEDIA_EXPORT int GetAudioHardwareSampleRate();
// Returns the audio input hardware sample-rate for the specified device.
-MEDIA_EXPORT double GetAudioInputHardwareSampleRate(
+MEDIA_EXPORT int GetAudioInputHardwareSampleRate(
const std::string& device_id);
// Returns the optimal low-latency buffer size for the audio hardware.
@@ -103,8 +102,8 @@ MEDIA_EXPORT double GetAudioInputHardwareSampleRate(
// at without glitches. The buffer size is in sample-frames.
MEDIA_EXPORT size_t GetAudioHardwareBufferSize();
-// Returns the number of channels for the specified audio input device.
-MEDIA_EXPORT uint32 GetAudioInputHardwareChannelCount(
+// Returns the channel layout for the specified audio input device.
+MEDIA_EXPORT ChannelLayout GetAudioInputHardwareChannelLayout(
const std::string& device_id);
// Functions that handle data buffer passed between processes in the shared
« no previous file with comments | « media/audio/audio_parameters_unittest.cc ('k') | media/audio/audio_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698